@@ -1,4 +1,4 @@
-# $Id: Document.pm 34998 2011-06-09 08:37:22Z wsl $
+# $Id: Document.pm 38127 2012-11-05 14:29:46Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/WS/ValidateCASv1/Document.pm $
 
 use strict;
@@ -16,5 +16,7 @@ sub response {
 
 	my $answer = defined $uid ? "yes\n$uid\n" : "no\n\n";
 
-	return new Xyzzy::Response(content => $answer);
+	my $res = new Xyzzy::Response(content => $answer);
+	$res->mimetype('text/plain', charset => 'UTF-8');
+	return $res;
 }
